/*
 * oma-ds-agent
 * Copyright (c) 2012 Samsung Electronics Co., Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 *   @SE_Account.h
 *   @version									0.1
 *   @brief										This file is the header file of interface of account
 */

#ifndef SE_ACCOUNT_H_
#define SE_ACCOUNT_H_

#include <glib.h>
#include <stdbool.h>
#include "common/common_define.h"

/**
 * @par Description: API to add profile API
 * This API can be used to add profile
 * This API is part of API for UI
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		string type, profile_dir_name(identify profile in UI)
 * @param[in]		string type, profile name
 * @param[in]		string type, server ip
 * @param[in]		string type, id
 * @param[in]		string type, password
 * @param[in]		int type, sync mode
 * @param[in]		int type, sync type
 * @param[in]		int type, interval(for periodic)
 * @param[in]		GList type, list of sync_service_s structure
 * @param[out]		int type, account id
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool add_profile(char *profile_name, char *addr, char *id, char *password, int sync_mode, int sync_type, int interval, GList * categories, int *account_id);

/**
 * @par Description: API to add profile from csc
 * This API can be used to add profile from csc(vconf)
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		int type, index of profile
 *
 * @return				1 on success
 *							0 on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool add_profile_csc(int index);

/**
 * @par Description: API to add profile API
 * This API can be used to add profile
 * This API is part of API for UI
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		string type, profile name
 * @param[in]		string type, server ip
 * @param[in]		string type, id
 * @param[in]		string type, password
 * @param[in]		GList type, list of resource_cp structure
 * @param[out]		int type, account id
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool add_profile_cp(char *profile_name, char *addr, char *id, char *password, GList * categories, int *account_id);

/**
 * @par Description: API to add profile for call log sync
 * This API can be used to add profile
 * This API is part of API for call log sync
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[out]		int type, account_id
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool add_profile_dive(int *account_id);

/**
 * @par Description: API to edit profile API
 * This API can be used to edit profile
 * This API is part of API for UI
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		int type, account id
 * @param[in]		string type, profile name
 * @param[in]		string type, server ip
 * @param[in]		string type, id
 * @param[in]		string type, password
 * @param[in]		int type, sync mode
 * @param[in]		int type, sync type
 * @param[in]		int type, interval(for periodic)
 * @param[in]		GList type, list of sync_service_s structure
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool edit_profile(int account_id, char *profile_name, char *addr, char *id, char *password, int sync_mode, int sync_type, int interval, GList * categories);

/**
 * @par Description: API to delete profile API
 * This API can be used to delete profile
 * This API is part of API for UI
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[in]		GList type, list of account id
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool delete_profiles(GList * profiles);

/**
 * @par Description: API to delete profile for call log sync
 * This API can be used to delete profile
 * This API is part of API for call log sync
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool delete_profile_dive();

/**
 * @par Description: API to delete profile
 * This API can be used to delete profile
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool delete_profile(char *access_name);

/**
 * @par Description: API to delete all profiles
 * This API can be used to delete all profiles
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool delete_all_profiles();

/**
 * @par Description: API to get profile directory name of synchronizing account
 * This API can be used to get profile directory name
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 * @param[out]		string type, profile_dir_name(identify profile in UI)
 * @param[out]		string type, sync_type(determined by server)
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool get_synchronising_profile(char **profile_dir_name, char **sync_type);

/**
 * @par Description: API to delete all agent default table(except id_provider_tbl, id_page_tbl)
 * This API can be used to delete all agent default table
 *
 * @par Purpose:
 * @par Typical use case:
 * @par Method of function operation:
 * @par Important notes:
 *
 * @return				true on success
 *							false on error
 *
 * @par Errors:
 *
 * @pre None.
 * @post
 * @see
 * @remarks None.
 *
 * @par Sample Code:
 * @code
 * @endcode
 */
bool delete_all_agent_default_table();

#endif				/* SE_ACCOUNT_H_ */
